@@ -30,22 +30,22 @@ class OriginalPID(Controller):
     def feed(self, state, t):
         dt = self.dt(t)
         phase = self.phase(t)
+        cycle_phase = self.cycle_phase(t)
 
         u_in = 0
-        if phase == Phase.RAMP_UP or phase == Phase.PIP:
+        if phase == Phase.RAMP_UP.value or phase == Phase.PIP.value:
             # __get_PID_error
-            pid_signal = self.PID.feed(state, t)
+            pid_signal = self.PID.feed(state, cycle_phase)
 
             # __calculate_control_signal_in
             self.filters[0] = pid_signal
             self.filters = np.roll(self.filters, -1)
             u_in = np.mean(self.filters)
 
-        elif phase == Phase.RAMP_DOWN:
+        elif phase == Phase.RAMP_DOWN.value:
             u_in = 0
 
         else:
-            u_in = 5 * (1 - np.exp(5 * (self.peep_time + self.i_phase) - t))
+            u_in = 5 * (1 - np.exp(5 * (self.peep_time + self.i_phase) - cycle_phase))
 
-
-        return (u_in, self.u_out(t))
+        return (u_in, self.u_out(cycle_phase))
